@@ -131,7 +131,8 @@ public enum OperationsId {
 	ExtractCodelist("11001"),
 	GuessCodelist("11002"),
 	CodelistMappingImport("12001"),
-	RuleOnColumnApply("1000000000");
+	RuleOnColumnApply("1000000000"),
+	ValidationsDelete("");
 	
 	
 	
